<?php

namespace Drupal\commerce_order_locking\EventSubscriber;

use Drupal\commerce_order_locking\Event\OrderWorkflowEvents;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Commerce order locking event subscriber.
 */
class OrderSubscriber implements EventSubscriberInterface {

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs event subscriber.
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(MessengerInterface $messenger) {
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      OrderWorkflowEvents::ORDER_LOCK => ['onCommerceOrderLock'],
      OrderWorkflowEvents::ORDER_UNLOCK => ['onCommerceOrderUnlock'],
    ];
  }

  public function onCommerceOrderLock(WorkflowTransitionEvent $event) {
    $event->getEntity()->lock();
  }

  public function onCommerceOrderUnlock(WorkflowTransitionEvent $event) {
    $event->getEntity()->unlock();
  }
}
