<?php

namespace Drupal\commerce_order_locking\Guard;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\state_machine\Guard\GuardInterface;
use Drupal\state_machine\Plugin\Workflow\WorkflowInterface;
use Drupal\state_machine\Plugin\Workflow\WorkflowTransition;

class OrderPermissionsGuard implements GuardInterface {

  protected $currentUser;

  public function __construct(AccountProxyInterface $current_user) {
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public function allowed(WorkflowTransition $transition, WorkflowInterface $workflow, EntityInterface $entity) {
    $transition_id = $transition->getId();
    if ($transition_id === 'unlock' || $transition_id === 'lock') {
      return AccessResult::allowedIfHasPermission($this->currentUser, "{$transition_id} {$entity->bundle()} {$entity->getEntityTypeId()}")
        ->orIf(AccessResult::allowedIfHasPermission($this->currentUser, "{$transition_id} {$entity->getEntityTypeId()}"))
        ->isAllowed();
    }
    return $this->neutral();
  }

  private function neutral() {
    return NULL;
  }

}
