<?php

namespace Drupal\commerce_order_locking;

use Drupal\commerce_order\Entity\OrderType;
use Drupal\Core\StringTranslation\StringTranslationTrait;

class OrderPermissions {

  use StringTranslationTrait;

  public function orderTypeLockPermissions() {
    $perms = [];
    // Generate node permissions for all node types.
    foreach (OrderType::loadMultiple() as $type) {
      $perms += $this->buildPermissions($type);
    }

    return $perms;
  }

  protected function buildPermissions(OrderType $type) {
    $type_id = $type->id();
    $type_params = ['%type_name' => $type->label()];

    return [
      "update locked $type_id commerce_order" => [
        'title' => $this->t('%type_name: Update <em>locked</em> orders', $type_params),
      ],
      "lock $type_id commerce_order" => [
        'title' => $this->t('%type_name: Lock orders', $type_params),
      ],
      "unlock $type_id commerce_order" => [
        'title' => $this->t('%type_name: Unlock orders', $type_params),
      ],
    ];
  }

}
