<?php

namespace Drupal\commerce_order_locking\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormState;
use Drupal\state_machine\Form\StateTransitionForm;
use Drupal\state_machine\Plugin\Field\FieldFormatter\StateTransitionFormFormatter;

/**
 * Plugin implementation of the 'state_transition_form' formatter.
 *
 * @FieldFormatter(
 *   id = "order_locking_transition_form",
 *   label = @Translation("Order locking transition form"),
 *   field_types = {
 *     "state",
 *   },
 * )
 */
class OrderLockingTransitionFormFormatter extends StateTransitionFormFormatter {

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    $is_applicable = parent::isApplicable($field_definition);
    return $is_applicable && ($field_definition->getTargetEntityTypeId() === 'commerce_order');
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    /** @var \Drupal\commerce_order\Entity\OrderInterface $entity */
    $entity = $items->getEntity();
    // Do not show the form if the user isn't allowed to modify the entity.
    $locked = $entity->isLocked();
    $access_operation = $locked ? 'unlock' : 'lock';
    if (!$entity->access($access_operation)) {
      return [];
    }
    /** @var \Drupal\state_machine\Form\StateTransitionFormInterface $form_object */
    $form_object = $this->classResolver->getInstanceFromDefinition(StateTransitionForm::class);
    $form_object->setEntity($entity);
    $form_object->setFieldName($items->getFieldDefinition()->getName());
    $form_state_additions = [];
    if ($this->supportsConfirmationForm()) {
      $form_state_additions += [
        // Store in the form state whether a confirmation is required before
        // applying the state transition.
        'require_confirmation' => (bool) $this->getSetting('require_confirmation'),
        'use_modal' => (bool) $this->getSetting('use_modal'),
      ];
    }
    $form_state = (new FormState())->setFormState($form_state_additions);
    // $elements needs a value for each delta. State fields can't be multivalue,
    // so it's safe to hardcode 0.
    $elements = [];
    $elements[0] = $this->formBuilder->buildForm($form_object, $form_state);

    return $elements;
  }
}
